#[non_exhaustive]pub enum Health {
Unspecified,
Healthy,
Timeout,
UnhealthyTensorflow,
UnhealthyMaintenance,
UnknownValue(UnknownValue),
}Expand description
Health defines the status of a TPU node as reported by Health Monitor.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Health status is unknown: not initialized or failed to retrieve.
Healthy
The resource is healthy.
Timeout
The resource is unresponsive.
UnhealthyTensorflow
The in-guest ML stack is unhealthy.
UnhealthyMaintenance
The node is under maintenance/priority boost caused rescheduling and will resume running once rescheduled.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Health::value or Health::name.
Implementations