#[non_exhaustive]pub struct DeleteQueuedResourceRequest {
pub name: String,
pub request_id: String,
pub force: bool,
/* private fields */
}Expand description
Request for DeleteQueuedResource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name.
request_id: StringOptional. Idempotent request UUID.
force: boolOptional. If set to true, all running nodes belonging to this queued resource will be deleted first and then the queued resource will be deleted. Otherwise (i.e. force=false), the queued resource will only be deleted if its nodes have already been deleted or the queued resource is in the ACCEPTED, FAILED, or SUSPENDED state.
Implementations