#[non_exhaustive]pub struct ServiceAccount {
pub email: String,
pub scope: Vec<String>,
/* private fields */
}Expand description
A service account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.email: StringEmail address of the service account. If empty, default Compute service account will be used.
scope: Vec<String>The list of scopes to be made available for this service account. If empty, access to all Cloud APIs will be allowed.
Implementations